=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2007-11-19 20:20:29 +0000
+++ bzrlib/config.py	2007-12-02 18:59:28 +0000
@@ -862,20 +862,29 @@
     return realname, (username + '@' + socket.gethostname())
 
 
+def parse_username(username):
+    """Parse e-mail username and return a (name, address) tuple."""
+    match = re.match(r'(.*?)\s*<?([\w+.-]+@[\w+.-]+)>?', username)
+    if match is None:
+        return (username, '')
+    else:
+        return (match.group(1), match.group(2))
+
+
 def extract_email_address(e):
     """Return just the address part of an email string.
-    
+
     That is just the user@domain part, nothing else. 
     This part is required to contain only ascii characters.
     If it can't be extracted, raises an error.
-    
+
     >>> extract_email_address('Jane Tester <jane@test.com>')
     "jane@test.com"
     """
-    m = re.search(r'[\w+.-]+@[\w+.-]+', e)
-    if not m:
+    name, email = parse_username(e)
+    if not email:
         raise errors.NoEmailInUsername(e)
-    return m.group(0)
+    return email
 
 
 class TreeConfig(IniBasedConfig):

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2007-12-01 11:06:45 +0000
+++ bzrlib/log.py	2007-12-02 18:59:28 +0000
@@ -53,6 +53,7 @@
 import re
 
 from bzrlib import (
+    config,
     lazy_regex,
     registry,
     symbol_versioning,
@@ -603,23 +604,17 @@
     def show(self, revno, rev, delta):
         raise NotImplementedError('not implemented in abstract base')
 
-    _short_name_re = lazy_regex.lazy_compile(r'(.*?)\s*<(.*@.*)>')
-
     def short_committer(self, rev):
-        name = rev.committer
-        match = self._short_name_re.match(name)
-        if match is None:
+        name, address = config.parse_username(rev.committer)
+        if name:
             return name
-        else:
-            return match.group(1) or match.group(2)
+        return address
 
     def short_author(self, rev):
-        name = rev.get_apparent_author()
-        match = self._short_name_re.match(name)
-        if match is None:
+        name, address = config.parse_username(rev.get_apparent_author())
+        if name:
             return name
-        else:
-            return match.group(1) or match.group(2)
+        return address
 
 
 class LongLogFormatter(LogFormatter):

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2007-11-23 16:10:09 +0000
+++ bzrlib/tests/test_config.py	2007-12-02 18:59:28 +0000
@@ -1083,6 +1083,15 @@
         self.assertRaises(errors.NoEmailInUsername,
                           config.extract_email_address, 'Jane Tester')
 
+    def test_parse_username(self):
+        self.assertEqual(('', 'jdoe@example.com'),
+                         config.parse_username('jdoe@example.com'))
+        self.assertEqual(('', 'jdoe@example.com'),
+                         config.parse_username('<jdoe@example.com>'))
+        self.assertEqual(('John Doe', 'jdoe@example.com'),
+                         config.parse_username('John Doe <jdoe@example.com>'))
+        self.assertEqual(('John Doe', ''),
+                         config.parse_username('John Doe'))
 
 class TestTreeConfig(tests.TestCaseWithTransport):
 

